## Question and Initial Evidence Collection

### Question

Here is the question we will set out to answer:

```text
{question}
```

### Initial Evidence

Now, we want to gather initial evidence provided in the question itself. This evidence will help guide our hypothesis creation later on.

#### NO PRIOR KNOWLEDGE ALLOWED

- No prior knowledge is to be included in the initial evidence.
- You cannot include plausible information in the evidence, it must be absolute.
- We might be operating in an alternate universe where 1+1=3, so do not make any assumptions.
- ONLY direct information from the question itself is to be included.